#!/bin/sh
#
# This script downloads the "all-in-one" zipfile from Xonotic upstream,
# strips it of its binary content and unneeded material,
# and creates an LZMA-compressed tarball for the source
# and a zipfile for the already-compressed data.
#
# Prepared for version 0.8.0, update if upstream changes its source distribution.

VERSION=0.8.2

if [ ! -e xonotic-$VERSION.zip ]
then
    echo "Retrieving all-in-one zipfile from upstream."
    wget -c http://dl.xonotic.org/xonotic-$VERSION.zip
fi

echo "Extracting the zipfile, this might take a while."
unzip xonotic-$VERSION.zip
pushd Xonotic

echo "Removing binary content and unneeded material."
# Win and Mac directories
rm -rf bin32 bin64 Xonotic.app
# Development tools
rm -rf misc/{infrastructure,tools}
# Binaries
rm -f xonotic*.exe xonotic-{linux{32,64},osx}*

mkdir ../xonotic-data-$VERSION
mv data ../xonotic-data-$VERSION/data
popd

mv Xonotic xonotic-$VERSION

echo "Preparing source and data tarballs."
tar cvJf xonotic-$VERSION.tar.xz xonotic-$VERSION/
# Compressing the data only in zip, because they are already-compressed pk3 files
# and LZMA does not bring much size gain (but is really slow to process 900+ MB)
zip -r -9 xonotic-data-$VERSION.zip xonotic-data-$VERSION/
